@@ -49,7 +49,9 @@
 #define BAD_MAIL_TMPL "%s:Cannot separate header part and body part."
 #define NO_HEADER "%s:Cannot find mail header data."
 
+# define NOTICEPASS_FROM 1
+# define NOTICEPASS_TO 2
 
-int tmpl_tag_replace(char *, struct mailzip, struct rcptinfo *, char *, char **);
-int tmpl_tag_replace_noconv(struct mailzip, struct rcptinfo *, char *, char **, char *);
+int tmpl_tag_replace(char *, struct mailzip, struct rcptinfo *, char *, char **, int);
+int tmpl_tag_replace_noconv(struct mailzip, struct rcptinfo *, char *, char **, char *, int);
 int tmpl_read(char **, char *);
