@@ -324,7 +324,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
 		mailzip_clean(mz);
 		return ZIP_CONVERT_FAILED;
 	    }
-#ifdef __CUSTOMIZE2018
+#ifdef __CUSTOMIZE2018_LOG
             if (ismode_enc) {
                 // for password log
                 if ((priv = MLFIPRIV(ctx)) == NULL) {
@@ -334,7 +334,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                 }
                 zipconv_log(msgid, from, p->rcptlist, mz.namelist, p->passwd);
             }
-#endif	// __CUSTOMIZE2018
+#endif	// __CUSTOMIZE2018_LOG
             /* send confirmation mail */
             if ((cfg->cf_fixedpassnotify[0] == 'Y' || cfg->cf_fixedpassnotify[0] == 'y')) {
                 org_p = p->passwd;	/* save original password */
@@ -429,7 +429,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                     free_rcptlist(rdm_all);
 	            return ZIP_CONVERT_FAILED;
 	        }
-#ifdef __CUSTOMIZE2018
+#ifdef __CUSTOMIZE2018_LOG
                 if (ismode_enc) {
                     // for password log
                     if ((priv = MLFIPRIV(ctx)) == NULL) {
@@ -439,7 +439,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                     }
                     zipconv_log(msgid, from, p->rcptlist, mz.namelist, p->passwd);
                 }
-#endif	// __CUSTOMIZE2018
+#endif	// __CUSTOMIZE2018_LOG
             } else {
                 /* 拡張子が指定されていない場合 */
                 /* まとめて送信するためのリストを作成 */
@@ -496,7 +496,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                 free_rcptlist(rdm_all);
                 return ZIP_CONVERT_FAILED;
             }
-#ifdef __CUSTOMIZE2018
+#ifdef __CUSTOMIZE2018_LOG
             if (ismode_enc) {
                 // for password log
                 if ((priv = MLFIPRIV(ctx)) == NULL) {
@@ -506,7 +506,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                 }
                 zipconv_log(msgid, from, tmp_rcptinfo.rcptlist, mz.namelist, tmp_rcptinfo.passwd);
             }
-#endif	// __CUSTOMIZE2018
+#endif	// __CUSTOMIZE2018_LOG
             free_rcptlist(rdm_noext);
         }
 
